@@ -299,9 +299,9 @@ define({
 	'ternDocPluginName': 'Doc Comments',
 	'ternDocPluginDescription': 'Tern plug-in to parse and use JSDoc-like comments for inferencing',
 	'ternCompleteStringsPluginName': 'String Completion',
-	'ternCompleteStringsPluginDescription': 'Tern plug-in to provided assist for previously seem strings.',
+	'ternCompleteStringsPluginDescription': 'Tern plug-in to provide assist for previously seen strings.',
 	'orionWebpackPluginName': 'Webpack',
-	'orionWebpackPluginDescription': 'Tern plug-in that handles Webpack modules resolution.',
+	'orionWebpackPluginDescription': 'Tern plug-in that handles Webpack module resolution.',
 	'orionAMQPPluginName': 'Orion AMQP',
 	'orionAMQPPluginDescription': 'Plug-in that contributes type information and code templates for AMQP.',
 	'orionAngularPluginName': 'AngularJS',
